/**
 * Array methods for (potentially) pre-ES5 environments
 *
 *  Copyright (C) 2014 Mike Gerwitz
 *
 *  This file is part of jsTonic.
 *
 *  jstonic is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

module.exports = {
    /**
     * Determines if the given object is an array primitive
     *
     * This will use the ECMAScript 5 Array.isArray method if available;
     * otherwise, it will fall back to the jsTonic implementation.
     *
     * @param {*} arr value to check
     * @return {boolean} whether the given value is an array primitive
     */
    isArray: Array.isArray || module.exports._isArray,


    /**
     * Pre-es5 method to determine if the given object is an array primitive
     *
     * @param {*} arr value to check
     * @return {boolean} whether the given value is an array primitive
     */
    _isArray: function( arr )
    {
        return ( Object.prototype.toString.call( arr ) === '[object Array]' );
    },
};

